{
    Respond, the fax number form daemon
    Copyright (C) 2000 Horst F <horstf@gmx.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}
unit Histfrm;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Header, PhBook, StdCtrls, Buttons, IniFile, Observer,
  StringObject, CommonDataAccess, History, ObservedStringList;

type
  THistForm = class(TForm)
    OKBtn: TBitBtn;
    CancelBtn: TBitBtn;
    PhBookBtn: TBitBtn;
    LBAlias: TListBox;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure PhBookBtnClick(Sender: TObject);
    procedure LBAliasClick(Sender: TObject);
    procedure OKBtnClick(Sender: TObject);
  private
    { Private-Deklarationen }
    HistoryEntriesCount: Integer;
    NotCommonEntriesCount: Integer;
    oResult: Integer;
  public
    { Public-Deklarationen }
    procedure GetSelectedItem(var number, receiver: String);
  end;

var
  HistForm: THistForm;

implementation

{$R *.DFM}

procedure THistForm.FormCreate(Sender: TObject);
begin
  Caption := CProgName+' '+GetLabelStr(KIHistory);
  OKBtn.Caption := GetLabelStr(KIOK);
  CancelBtn.Caption := GetLabelStr(KICancel);
  PhBookBtn.Caption := UnShortCut(GetLabelStr(KIPhoneBook));
end;

procedure THistForm.FormShow(Sender: TObject);
{ Initialize list and phonebook button }
var
  i, j : Integer;
  number, receiver : String;
begin
  LBAlias.Items.Clear;
  j := THistory.Count;
  try
    for i := 1 to j do begin
      if THistory.Get(i, number, receiver) then begin
        LBAlias.Items.Add(number + ': ' + receiver);
      end;
    end;
  except
    on EOutOfMemory do begin
      MessageDlg(GetLabelStr(KIErrOutOfMemory), mtError, [mbOK], 0);
    end;
  end;
  HistoryEntriesCount := LBAlias.Items.Count;
  TCommonData.ReadTableKeys(PrivatePhonebookSection, LBAlias.Items);
  NotCommonEntriesCount := LBAlias.Items.Count;
  TCommonData.ReadTableKeys(CommonPhonebookSection, LBAlias.Items);
  LBAlias.ItemIndex := 0;
  PhBookBtn.Enabled := LBAlias.Items.Count > 0;
  oResult := -1;
end;

procedure THistForm.PhBookBtnClick(Sender: TObject);
{ ShowModal phonebook form with some edit fields preset from
  selected list item }
var
  j : Integer;
  alias, num, recv : String;
  form : TPhBookForm;
  sl : TSTringList;
begin
  Enabled := false;
  j := LBAlias.ItemIndex;
  if j >= 0 then begin
    alias := '';
    num := '';
    recv := '';
    if j < HistoryEntriesCount then begin
      THistory.Get(j+1, num, recv);
    end else begin
      alias := LBAlias.Items[j];
      sl := nil;
      try
        sl := TObservedStringList.Create;
        TCommonData.ReadFields(PrivatePhonebookSection, alias, sl);
        if sl.Count > 0 then num := sl.Strings[0];
        if sl.Count > 1 then recv := sl.Strings[1];
      except
        on EOutOfMemory do begin
          MessageDlg(GetLabelStr(KIErrOutOfMemory), mtError, [mbOK], 0);
        end;
      end;
      sl.Free;
    end;
    if Length(Trim(num)) > 0 then begin
      form := TPhBookForm.Create(self);
      form.Preset(alias, num, recv);
      form.ShowModal;
    end;
  end;
  Enabled := True;
end;

procedure THistForm.LBAliasClick(Sender: TObject);
{ Replacement for OnChange list event }
var
  i : Integer;
begin
  i := LBAlias.ItemIndex;
  PhBookBtn.Enabled := (i >= 0) and (i < NotCommonEntriesCount);
end;

procedure THistForm.OKBtnClick(Sender: TObject);
begin
  oResult := LBAlias.ItemIndex;
end;

procedure THistForm.GetSelectedItem(var number, receiver: String);
var
  alias : String;
  sl : TObservedStringList;
begin
  number := '';
  receiver := '';
  if (oResult >= 0) and (oResult < LBAlias.Items.Count) then begin
    if oResult < HistoryEntriesCount then begin
      THistory.Get(oResult+1, number, receiver);
    end else begin
      alias := LBAlias.Items[oResult];
      sl := nil;
      try
        sl := TObservedStringList.Create;
        if oResult < NotCommonEntriesCount then begin
          TCommonData.ReadFields(PrivatePhonebookSection, alias, sl);
        end else begin
          TCommonData.ReadFields(CommonPhonebookSection, alias, sl);
        end;
        if sl.Count > 1 then begin
          number := sl[0];
          if sl.Count > 2 then receiver := sl[1];
        end;
      except
        on EOutOfMemory do begin
          MessageDlg(GetLabelStr(KIErrOutOfMemory), mtError, [mbOK], 0);
        end;
      end;
      sl.Free;
    end;
  end
end;

end.
